@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # Copyright (c) the purl authors
+# SPDX-License-Identifier: MIT
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -55,17 +56,20 @@ in this single Python script.
 purl_router = Router()
 
 
-def get_purl(uri):
+def url2purl(url):
     """
-    Return a PackageURL inferred from the `uri` string or None.
+    Return a PackageURL inferred from the `url` string or None.
     """
-    if uri:
+    if url:
         try:
-            return purl_router.process(uri)
+            return purl_router.process(url)
         except NoRouteAvailable:
             return
 
 
+get_purl = url2purl
+
+
 def purl_from_pattern(type_, pattern, url):
     url = unquote_plus(url)
     compiled_pattern = re.compile(pattern, re.VERBOSE)
@@ -244,7 +248,7 @@ nuget_pattern1 = (
 
 
 @purl_router.route(nuget_pattern1)
-def build_nuget_purl(uri):
+def build_nuget_purl1(uri):
     return purl_from_pattern('nuget', nuget_pattern1, uri)
 
 
@@ -258,7 +262,7 @@ nuget_pattern2 = (
 
 
 @purl_router.route(nuget_pattern2)
-def build_nuget_purl(uri):
+def build_nuget_purl2(uri):
     return purl_from_pattern('nuget', nuget_pattern2, uri)
 
 
@@ -343,7 +347,7 @@ def build_github_api_purl(url):
 
 github_codeload_pattern = (
     r"https?://codeload.github.com/"
-    r"(?P<namespace>.+)/(?P<name>.+)/(zip|tar.gz|tar.bz2|.tgz)/v(?P<version>.+)$"
+    r"(?P<namespace>.+)/(?P<name>.+)/(zip|tar.gz|tar.bz2|.tgz)/v?(?P<version>.+)$"
 )
 
 
@@ -367,17 +371,27 @@ def build_github_purl(url):
     https://github.com/package-url/packageurl-js or
     https://github.com/nexB/scancode-toolkit/archive/v3.1.1.zip
     """
-    #https://github.com/nexB/scancode-toolkit/archive/v3.1.1.zip
-    gh_pattern = r"https?://github.com/(?P<namespace>.+)/(?P<name>.+)/archive/v(?P<version>.+).(zip|tar.gz|tar.bz2|.tgz)"
-    matches = re.search(gh_pattern, url)
+    # https://github.com/nexB/scancode-toolkit/archive/v3.1.1.zip
+    archive_pattern = (
+        r"https?://github.com/(?P<namespace>.+)/(?P<name>.+)"
+        r"/archive/v?(?P<version>.+).(zip|tar.gz|tar.bz2|.tgz)"
+    )
 
-    if matches:
-        return purl_from_pattern(type_='github', pattern=gh_pattern, url=url)
+    # https://github.com/pypa/get-virtualenv/raw/20.0.31/public/virtualenv.pyz
+    raw_pattern = (
+        r"https?://github.com/(?P<namespace>.+)/(?P<name>.+)"
+        r"/raw/v?(?P<version>[^/]+)/(?P<subpath>.*)$"
+    )
+
+    for pattern in [archive_pattern, raw_pattern]:
+        matches = re.search(pattern, url)
+        if matches:
+            return purl_from_pattern(type_='github', pattern=pattern, url=url)
 
     segments = get_path_segments(url)
-
-    if segments==[]:
+    if not segments:
         return
+
     namespace = segments[0]
     name = segments[1]
     version = None
